body {
  font-family: sans-serif;
  margin: 0;
  padding: 0;
}

h1,
h2,
p {
  margin: 0;
  padding: 0.5rem 0 0 0;
  font-weight: normal;
}

h1,
h2 {
  color: #222244;
}

header {
  padding: 0.5rem 2rem 0.5rem 2rem;
  background: #f0f0f4;
  border-bottom: 1px solid #aaaabb;
}

main {
  padding: 0.5rem 2rem 0.5rem 2rem;
}

.form-field {
  display: block;
  margin: 1rem;
}

.hidden {
  display: none;
}
